mafw.ui.abstract\_user\_interface
=================================

.. automodule:: mafw.ui.abstract_user_interface

   
   .. rubric:: Classes

   .. autosummary::
   
      UserInterfaceBase
      UserInterfaceMeta
   